Named objects that publish and request strongly-typed data to named topics on the Host
Structs
- Active
- State marker for a Node capable of manually sending publish/request messages
- Idle
- State marker for a Node that has not been connected to a Host
- Node
- A named, strongly-typed Node capable of publish/request on Host
- Node
Config - Configuration of strongly-typed Node
- Subscription
- State marker for a Node with an active topic subscription
- Subscription
Data - Composite data comprised of Bissel-compatible data and a String timestamp
Traits
- Message
- Trait for Bissel-compatible data, requiring serde De\Serialize, Debug, and Clone
Functions
- await_
response - Set Node to wait for GenericMsg response from Host, with data to be deserialized into Node’s
-type - handshake
- Run the initial Node <=> Host connection handshake
- send_
msg - Send a GenericMsg of MsgType from the Node to the Host
- try_
connection - Attempts to create an async TcpStream connection with a Host at the specified socket address